examples Package — pySAXS 77.September2012 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pySAXS 77.September2012 documentation »
- pySAXS »
- pySAXS Package »

# examples Package

## `absoluteScalingWithoutPredifinedParameters` Module

example of use for open a data file (rgr) and set in absolute scale Without predefined absolute parameters

## `calculateAbsorption` Module

example of use for the absorption module

## `calculateInvariant` Module

example of importing data from a xml dataset and calculate invariant with different parameters

## `importDataset` Module

Example for importing and plotting data from a xml dataset

## `openDataAndAbsoluteScale` Module

example of use for open a data file (rgr) and set in absolute scale datas and parameter xml file are in saxsdata

## `plottingDataAndFit` Module

example of use for open a data file (rgr) , plot, and fit by a model

### Navigation

- index
- modules |
- next |
- previous |
- pySAXS 77.September2012 documentation »
- pySAXS »
- pySAXS Package »